============
Installation
============

At the command line::

    $ pip install Boiler-Plate

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv Boiler-Plate
    $ pip install Boiler-Plate
